@@ -2,7 +2,9 @@ import csv
 import logging
 import re
 import sys
+import tempfile
 from io import StringIO
+from pathlib import Path
 
 from django.db import models, transaction
 
@@ -589,23 +591,29 @@ class OculScholarsPortalPreservation(models.Model):
     @transaction.atomic
     def import_data(url, bucket="", s3client=None):
         # download the data file from S3 bucket
-        xml_file = utils.download_remote(False, OculScholarsPortalPreservation,
-                                         url, bucket=bucket, s3client=s3client,
-                                         decode=False)
+        with tempfile.TemporaryDirectory() as tmp:
+            path = Path(tmp) / 'downloaded.file'
 
-        # clear out
-        utils.clear_out(OculScholarsPortalPreservation)
+            xml_file = utils.download_remote(False,
+                                             OculScholarsPortalPreservation,
+                                             url, bucket=bucket,
+                                             s3client=s3client,
+                                             decode=False, file=True,
+                                             filename=path)
 
-        fields = ['oph:ResourceVersionIDType', 'oph:IDValue',
-                  'oph:FixedCoverage', 'oph:PreservationStatusCode',
-                  'oph:VerificationStatus']
+            # local file for testing
+            # xml_file = '/home/martin/scholars_portal_keepers_20230202.xml'
 
-        xml_parsed = utils.process_onix(
-            xml_file, fields,
-            callback=OculScholarsPortalPreservation.create_preservation)
+            # clear out
+            utils.clear_out(OculScholarsPortalPreservation)
 
-        for ocul_item in xml_parsed:
-            print(ocul_item)
+            fields = ['oph:ResourceVersionIDType', 'oph:IDValue',
+                      'oph:FixedCoverage', 'oph:PreservationStatusCode',
+                      'oph:VerificationStatus']
+
+            xml_parsed = utils.process_onix(
+                xml_file, fields,
+                callback=OculScholarsPortalPreservation.create_preservation)
 
     @staticmethod
     def create_preservation(output) -> None:
@@ -618,12 +626,20 @@ class OculScholarsPortalPreservation(models.Model):
         publisher, created = \
             Publisher.objects.get_or_create(name=output['publisher'])
 
-        OculScholarsPortalPreservation.objects.create(
-            issn=output['issn'], title=output['title'],
-            preserved_volumes=output['volume'],
-            preserved_no=output['issue'], preserved=output['status'],
-            verified=output['verification'], publisher=publisher
-        )
+        volumes = output['volumes']
+        issues = output['issues']
 
-        logging.info(f'Added {output["title"]} to '
-                     f'{OculScholarsPortalPreservation.name()} data')
+        for volume, issue in zip(volumes, issues):
+
+            volume = volume if volume is not None else ''
+            issue = issue if issue is not None else ''
+
+            OculScholarsPortalPreservation.objects.create(
+                issn=output['issn'], title=output['title'],
+                preserved_volumes=volume, preserved_no=issue,
+                preserved=output['status'], verified=output['verification'],
+                publisher=publisher
+            )
+
+            logging.info(f'Added {output["title"]} ({volume}.{issue}) to '
+                         f'{OculScholarsPortalPreservation.name()} data')
